@@ -26,7 +26,8 @@
 
 GdkPixbuf *notify_pixbuf_from_image_data (GVariant *image_data);
 
-gchar     *notify_icon_name_from_desktop_id (const gchar *desktop_id);
+gchar     *notify_get_from_desktop_file (const gchar *desktop_file,
+                                         const gchar *key);
 
 GKeyFile  *xfce_notify_log_get (void);
 
